@@ -2,14 +2,8 @@ from pathlib import Path
 import json
 import copy
 
-# pylint: disable=unused-import
-from unittest.mock import Mock, patch
-import unittest.mock as mock
-
 import pytest
-import requests_mock
 import shapely
-from geojson import Feature
 
 # pylint: disable=unused-import,wrong-import-order
 from .context import Workflow, Job, JobCollection
@@ -22,139 +16,26 @@ from .fixtures import (
     jobcollection_single_mock,
     jobtask_mock,
     project_mock,
-    project_max_concurrent_jobs,
+    project_mock_max_concurrent_jobs,
 )
-import up42
+from .fixtures import JOB_ID, JOB_NAME, JOBTASK_ID
 
 
-json_workflow_tasks = {
-    "data": [
-        {
-            "id": "c0d04ec3-98d7-4183-902f-5bcb2a176d89",
-            "name": "sobloo-s2-l1c-aoiclipped:1",
-            "block": {
-                "name": "sobloo-s2-l1c-aoiclipped",
-                "parameters": {
-                    "nodata": {"type": "number",},
-                    "time": {
-                        "type": "dateRange",
-                        "default": "2018-01-01T00:00:00+00:00/2020-12-31T23:59:59+00:00",
-                    },
-                },
-            },
-        },
-        {
-            "id": "af626c54-156e-4f13-a743-55efd27de533",
-            "name": "tiling:1",
-            "block": {
-                "name": "tiling",
-                "parameters": {
-                    "nodata": {
-                        "type": "number",
-                        "default": None,
-                        "required": False,
-                        "description": "Value representing..",
-                    },
-                    "tile_width": {
-                        "type": "number",
-                        "default": 768,
-                        "required": True,
-                        "description": "Width of a tile in pixels",
-                    },
-                },
-            },
-        },
-    ],
-    "error": {},
-}
+def test_workflow_info(workflow_mock):
+    del workflow_mock._info
 
-json_blocks = {
-    "data": [
-        {
-            "id": "4ed70368-d4e1-4462-bef6-14e768049471",
-            "name": "tiling",
-            "displayName": "Raster Tiling",
-        },
-        {
-            "id": "c0d04ec3-98d7-4183-902f-5bcb2a176d89",
-            "name": "sharpening",
-            "displayName": "Sharpening Filter",
-        },
-        {
-            "id": "a2daaab4-196d-4226-a018-a810444dcad1",
-            "name": "sobloo-s2-l1c-aoiclipped",
-            "displayName": "Sentinel-2 L1C MSI AOI clipped",
-        },
-    ],
-    "error": {},
-}
-
-
-def test_workflow_get_info(workflow_mock):
-    del workflow_mock.info
-
-    with requests_mock.Mocker() as m:
-        url_workflow_info = (
-            f"{workflow_mock.auth._endpoint()}/projects/"
-            f"{workflow_mock.project_id}/workflows/"
-            f"{workflow_mock.workflow_id}"
-        )
-        m.get(url=url_workflow_info, json={"data": {"xyz": 789}, "error": {}})
-
-        info = workflow_mock._get_info()
     assert isinstance(workflow_mock, Workflow)
-    assert info["xyz"] == 789
     assert workflow_mock.info["xyz"] == 789
-
-
-def test_get_compatible_blocks(workflow_mock):
-    url_workflow_tasks = (
-        f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.auth.project_id}/workflows/"
-        f"{workflow_mock.workflow_id}/tasks"
-    )
-    with requests_mock.Mocker() as m:
-        m.get(url=url_workflow_tasks, json=json_workflow_tasks)
-
-        url_compatible_blocks = (
-            f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.project_id}/"
-            f"workflows/{workflow_mock.workflow_id}/"
-            f"compatible-blocks?parentTaskName=tiling:1"
-        )
-        json_compatible_blocks = {
-            "data": {
-                "blocks": [
-                    {"blockId": "aaa123", "name": "aaa", "versionTag": "2.0"},
-                    {"blockId": "bbb123", "name": "bbb", "versionTag": "2.0"},
-                ],
-                "error": {},
-            }
-        }
-        m.get(url=url_compatible_blocks, json=json_compatible_blocks)
-
-        compatible_blocks = workflow_mock.get_compatible_blocks()
-    assert isinstance(compatible_blocks, dict)
-    assert "aaa" in list(compatible_blocks.keys())
-
-
-@pytest.mark.live
-def test_get_compatible_blocks_live(workflow_live):
-    compatible_blocks = workflow_live.get_compatible_blocks()
-    assert isinstance(compatible_blocks, dict)
-    assert "tiling" in list(compatible_blocks.keys())
+    assert workflow_mock._info["xyz"] == 789
 
 
 def test_get_workflow_tasks_normal_and_basic(workflow_mock):
-    url_workflow_tasks = (
-        f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.auth.project_id}/workflows/"
-        f"{workflow_mock.workflow_id}/tasks"
-    )
-    with requests_mock.Mocker() as m:
-        m.get(url=url_workflow_tasks, json=json_workflow_tasks)
-        tasks = workflow_mock.get_workflow_tasks(basic=False)
+    tasks = workflow_mock.get_workflow_tasks(basic=False)
     assert len(tasks) == 2
     assert tasks[0] == {
         "id": "c0d04ec3-98d7-4183-902f-5bcb2a176d89",
         "name": "sobloo-s2-l1c-aoiclipped:1",
+        "blockVersionTag": "2.2.2",
         "block": {
             "name": "sobloo-s2-l1c-aoiclipped",
             "parameters": {
@@ -167,11 +48,10 @@ def test_get_workflow_tasks_normal_and_basic(workflow_mock):
         },
     }
 
-    with requests_mock.Mocker() as m:
-        m.get(url=url_workflow_tasks, json=json_workflow_tasks)
-        tasks = workflow_mock.get_workflow_tasks(basic=True)
+    tasks = workflow_mock.get_workflow_tasks(basic=True)
     assert len(tasks) == 2
-    assert tasks["sobloo-s2-l1c-aoiclipped:1"] == "c0d04ec3-98d7-4183-902f-5bcb2a176d89"
+    assert tasks["sobloo-s2-l1c-aoiclipped:1"] == "2.2.2"
+    assert tasks["tiling:1"] == "1.0.0"
 
 
 @pytest.mark.live
@@ -181,15 +61,23 @@ def test_get_workflow_tasks_live(workflow_live):
     assert "sobloo-s2-l1c-aoiclipped:1" in list(workflow_tasks.keys())
 
 
+def test_get_compatible_blocks(workflow_mock):
+    compatible_blocks = workflow_mock.get_compatible_blocks()
+    assert isinstance(compatible_blocks, dict)
+    assert "aaa" in list(compatible_blocks.keys())
+
+
+@pytest.mark.live
+def test_get_compatible_blocks_live(workflow_live):
+    compatible_blocks = workflow_live.get_compatible_blocks()
+    assert isinstance(compatible_blocks, dict)
+    assert "tiling" in list(compatible_blocks.keys())
+
+
 def test_construct_full_workflow_tasks_dict_unkwown_block_raises(workflow_mock):
     input_tasks = ["some_block"]
-    with requests_mock.Mocker() as m:
-        url_get_blocks = f"{workflow_mock.auth._endpoint()}/blocks"
-        m.get(
-            url=url_get_blocks, json=json_blocks,
-        )
-        with pytest.raises(ValueError):
-            workflow_mock._construct_full_workflow_tasks_dict(input_tasks=input_tasks)
+    with pytest.raises(ValueError):
+        workflow_mock._construct_full_workflow_tasks_dict(input_tasks=input_tasks)
 
 
 @pytest.mark.parametrize(
@@ -200,20 +88,24 @@ def test_construct_full_workflow_tasks_dict_unkwown_block_raises(workflow_mock):
             "4ed70368-d4e1-4462-bef6-14e768049471",
         ],
         ["sobloo-s2-l1c-aoiclipped", "tiling"],
-        ["Sentinel-2 L1C MSI AOI clipped", "Raster Tiling",],
-        ["a2daaab4-196d-4226-a018-a810444dcad1", "tiling",],
-        ["Sentinel-2 L1C MSI AOI clipped", "4ed70368-d4e1-4462-bef6-14e768049471",],
+        [
+            "Sentinel-2 L1C MSI AOI clipped",
+            "Raster Tiling",
+        ],
+        [
+            "a2daaab4-196d-4226-a018-a810444dcad1",
+            "tiling",
+        ],
+        [
+            "Sentinel-2 L1C MSI AOI clipped",
+            "4ed70368-d4e1-4462-bef6-14e768049471",
+        ],
     ],
 )
 def test_construct_full_workflow_tasks_dict(workflow_mock, input_tasks):
-    with requests_mock.Mocker() as m:
-        url_get_blocks = f"{workflow_mock.auth._endpoint()}/blocks"
-        m.get(
-            url=url_get_blocks, json=json_blocks,
-        )
-        full_workflow_tasks_dict = workflow_mock._construct_full_workflow_tasks_dict(
-            input_tasks=input_tasks
-        )
+    full_workflow_tasks_dict = workflow_mock._construct_full_workflow_tasks_dict(
+        input_tasks=input_tasks
+    )
     assert isinstance(full_workflow_tasks_dict, list)
     assert full_workflow_tasks_dict[0]["name"] == "sobloo-s2-l1c-aoiclipped:1"
     assert full_workflow_tasks_dict[0]["parentName"] is None
@@ -224,9 +116,7 @@ def test_construct_full_workflow_tasks_dict(workflow_mock, input_tasks):
     )
 
 
-@pytest.mark.skip
-# TODO: Resolve
-def test_add_workflow_tasks_full(workflow_mock, caplog):
+def test_add_workflow_tasks_full(workflow_mock, requests_mock):
     input_tasks_full = [
         {
             "name": "sobloo-s2-l1c-aoiclipped:1",
@@ -239,16 +129,14 @@ def test_add_workflow_tasks_full(workflow_mock, caplog):
             "blockId": "4ed70368-d4e1-4462-bef6-14e768049471",
         },
     ]
-
     job_url = (
         f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.project_id}/workflows/"
         f"{workflow_mock.workflow_id}/tasks/"
     )
-    with requests_mock.Mocker() as m:
-        m.post(url=job_url, status_code=200)
+    requests_mock.post(url=job_url, status_code=200)
 
-        workflow_mock.add_workflow_tasks(input_tasks_full)
-    assert f"Added tasks to workflow: {input_tasks_full}" in caplog.text
+    workflow_mock.add_workflow_tasks(input_tasks_full)
+    # TODO:caplog, capture logger
 
 
 @pytest.mark.live
@@ -259,13 +147,7 @@ def test_add_workflow_tasks_simple_not_existing_block_id_raises_live(workflow_li
 
 
 def test_get_parameter_info(workflow_mock):
-    url_workflow_tasks = (
-        f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.auth.project_id}/workflows/"
-        f"{workflow_mock.workflow_id}/tasks"
-    )
-    with requests_mock.Mocker() as m:
-        m.get(url=url_workflow_tasks, json=json_workflow_tasks)
-        parameter_info = workflow_mock.get_parameters_info()
+    parameter_info = workflow_mock.get_parameters_info()
     assert isinstance(parameter_info, dict)
     assert all(
         x in list(parameter_info.keys())
@@ -291,13 +173,7 @@ def test_get_parameter_info_live(workflow_live):
 
 
 def test_get_default_parameters(workflow_mock):
-    url_workflow_tasks = (
-        f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.auth.project_id}/workflows/"
-        f"{workflow_mock.workflow_id}/tasks"
-    )
-    with requests_mock.Mocker() as m:
-        m.get(url=url_workflow_tasks, json=json_workflow_tasks)
-        default_parameters = workflow_mock._get_default_parameters()
+    default_parameters = workflow_mock._get_default_parameters()
     assert isinstance(default_parameters, dict)
     assert all(
         x in list(default_parameters.keys())
@@ -310,24 +186,17 @@ def test_get_default_parameters(workflow_mock):
 
 
 def test_construct_parameters(workflow_mock):
-    url_workflow_tasks = (
-        f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.auth.project_id}/workflows/"
-        f"{workflow_mock.workflow_id}/tasks"
+    parameters = workflow_mock.construct_parameters(
+        geometry=shapely.geometry.point.Point(1, 3),
+        geometry_operation="bbox",
+        start_date="2014-01-01",
+        end_date="2016-12-31",
+        limit=1,
     )
-    with requests_mock.Mocker() as m:
-        m.get(url=url_workflow_tasks, json=json_workflow_tasks)
-
-        parameters = workflow_mock.construct_parameters(
-            geometry=shapely.geometry.point.Point(1, 3),
-            geometry_operation="bbox",
-            start_date="2014-01-01",
-            end_date="2016-12-31",
-            limit=1,
-        )
     assert isinstance(parameters, dict)
     assert parameters == {
         "sobloo-s2-l1c-aoiclipped:1": {
-            "time": "2014-01-01T00:00:00Z/2016-12-31T00:00:00Z",
+            "time": "2014-01-01T00:00:00Z/2016-12-31T23:59:59Z",
             "limit": 1,
             "bbox": [0.99999, 2.99999, 1.00001, 3.00001],
         },
@@ -336,18 +205,11 @@ def test_construct_parameters(workflow_mock):
 
 
 def test_construct_parameters_scene_ids(workflow_mock):
-    url_workflow_tasks = (
-        f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.auth.project_id}/workflows/"
-        f"{workflow_mock.workflow_id}/tasks"
+    parameters = workflow_mock.construct_parameters(
+        geometry=shapely.geometry.point.Point(1, 3),
+        geometry_operation="bbox",
+        scene_ids=["s2_123223"],
     )
-    with requests_mock.Mocker() as m:
-        m.get(url=url_workflow_tasks, json=json_workflow_tasks)
-
-        parameters = workflow_mock.construct_parameters(
-            geometry=shapely.geometry.point.Point(1, 3),
-            geometry_operation="bbox",
-            scene_ids=["s2_123223"],
-        )
     assert isinstance(parameters, dict)
     assert parameters == {
         "sobloo-s2-l1c-aoiclipped:1": {
@@ -360,14 +222,9 @@ def test_construct_parameters_scene_ids(workflow_mock):
 
 
 def test_construct_parameter_only_ids(workflow_mock):
-    url_workflow_tasks = (
-        f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.auth.project_id}/workflows/"
-        f"{workflow_mock.workflow_id}/tasks"
+    parameters = workflow_mock.construct_parameters(
+        scene_ids=["s2_123223"],
     )
-    with requests_mock.Mocker() as m:
-        m.get(url=url_workflow_tasks, json=json_workflow_tasks)
-
-        parameters = workflow_mock.construct_parameters(scene_ids=["s2_123223"],)
     assert isinstance(parameters, dict)
     assert parameters == {
         "sobloo-s2-l1c-aoiclipped:1": {"ids": ["s2_123223"], "limit": 1},
@@ -376,14 +233,7 @@ def test_construct_parameter_only_ids(workflow_mock):
 
 
 def test_construct_parameter_order_ids(workflow_mock):
-    url_workflow_tasks = (
-        f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.auth.project_id}/workflows/"
-        f"{workflow_mock.workflow_id}/tasks"
-    )
-    with requests_mock.Mocker() as m:
-        m.get(url=url_workflow_tasks, json=json_workflow_tasks)
-
-        parameters = workflow_mock.construct_parameters(order_ids=["8472712912"])
+    parameters = workflow_mock.construct_parameters(order_ids=["8472712912"])
     assert isinstance(parameters, dict)
     assert parameters == {
         "sobloo-s2-l1c-aoiclipped:1": {"order_ids": ["8472712912"]},
@@ -392,26 +242,19 @@ def test_construct_parameter_order_ids(workflow_mock):
 
 
 def test_construct_parameters_parallel(workflow_mock):
-    url_workflow_tasks = (
-        f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.auth.project_id}/workflows/"
-        f"{workflow_mock.workflow_id}/tasks"
+    parameters_list = workflow_mock.construct_parameters_parallel(
+        geometries=[
+            shapely.geometry.point.Point(1, 3),
+            shapely.geometry.point.Point(1, 5),
+        ],
+        interval_dates=[("2014-01-01", "2016-12-31")],
+        geometry_operation="bbox",
     )
-    with requests_mock.Mocker() as m:
-        m.get(url=url_workflow_tasks, json=json_workflow_tasks)
-
-        parameters_list = workflow_mock.construct_parameters_parallel(
-            geometries=[
-                shapely.geometry.point.Point(1, 3),
-                shapely.geometry.point.Point(1, 5),
-            ],
-            interval_dates=[("2014-01-01", "2016-12-31")],
-            geometry_operation="bbox",
-        )
     assert isinstance(parameters_list, list)
     assert len(parameters_list) == 2
     assert parameters_list[0] == {
         "sobloo-s2-l1c-aoiclipped:1": {
-            "time": "2014-01-01T00:00:00Z/2016-12-31T00:00:00Z",
+            "time": "2014-01-01T00:00:00Z/2016-12-31T23:59:59Z",
             "limit": 1,
             "bbox": [0.99999, 2.99999, 1.00001, 3.00001],
         },
@@ -420,48 +263,32 @@ def test_construct_parameters_parallel(workflow_mock):
 
 
 def test_construct_parameters_parallel_multiple_intervals(workflow_mock):
-    url_workflow_tasks = (
-        f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.auth.project_id}/workflows/"
-        f"{workflow_mock.workflow_id}/tasks"
+    parameters_list = workflow_mock.construct_parameters_parallel(
+        geometries=[
+            shapely.geometry.point.Point(1, 3),
+            shapely.geometry.point.Point(1, 5),
+        ],
+        interval_dates=[("2014-01-01", "2016-12-31"), ("2017-01-01", "2019-12-31")],
+        geometry_operation="bbox",
     )
-    with requests_mock.Mocker() as m:
-        m.get(url=url_workflow_tasks, json=json_workflow_tasks)
-
-        parameters_list = workflow_mock.construct_parameters_parallel(
-            geometries=[
-                shapely.geometry.point.Point(1, 3),
-                shapely.geometry.point.Point(1, 5),
-            ],
-            interval_dates=[("2014-01-01", "2016-12-31"), ("2017-01-01", "2019-12-31")],
-            geometry_operation="bbox",
-        )
     assert len(parameters_list) == 4
     assert parameters_list[0] == {
         "sobloo-s2-l1c-aoiclipped:1": {
-            "time": "2014-01-01T00:00:00Z/2016-12-31T00:00:00Z",
+            "time": "2014-01-01T00:00:00Z/2016-12-31T23:59:59Z",
             "limit": 1,
             "bbox": [0.99999, 2.99999, 1.00001, 3.00001],
         },
         "tiling:1": {"tile_width": 768},
     }
 
-    with requests_mock.Mocker() as m:
-        m.get(url=url_workflow_tasks, json=json_workflow_tasks)
-        with pytest.raises(ValueError):
-            workflow_mock.construct_parameters_parallel(geometries=None)
+    with pytest.raises(ValueError):
+        workflow_mock.construct_parameters_parallel(geometries=None)
 
 
 def test_construct_parameters_parallel_scene_ids(workflow_mock):
-    url_workflow_tasks = (
-        f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.auth.project_id}/workflows/"
-        f"{workflow_mock.workflow_id}/tasks"
+    parameters_list = workflow_mock.construct_parameters_parallel(
+        scene_ids=["S2abc", "S2123"]
     )
-    with requests_mock.Mocker() as m:
-        m.get(url=url_workflow_tasks, json=json_workflow_tasks)
-
-        parameters_list = workflow_mock.construct_parameters_parallel(
-            scene_ids=["S2abc", "S2123"]
-        )
     assert len(parameters_list) == 2
     assert parameters_list[0] == {
         "sobloo-s2-l1c-aoiclipped:1": {"ids": ["S2abc"], "limit": 1},
@@ -469,29 +296,25 @@ def test_construct_parameters_parallel_scene_ids(workflow_mock):
     }
 
 
-def test_run_job(workflow_mock, job_mock):
-    with requests_mock.Mocker() as m:
-        job_name = f"{workflow_mock.info['name']}_py"
-        job_url = (
-            f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.project_id}/"
-            f"workflows/{workflow_mock.workflow_id}/jobs?name={job_name}"
-        )
-        m.post(url=job_url, json={"data": {"id": job_mock.job_id}})
-        input_parameters_json = (
-            Path(__file__).resolve().parent / "mock_data/input_params_simple.json"
-        )
-        m.get(
-            url=f"{job_mock.auth._endpoint()}/projects/{job_mock.project_id}/"
-            f"jobs/{job_mock.job_id}",
-            json={"data": {}},
-        )
+def test_run_job(workflow_mock, job_mock, requests_mock):
+    # job info
+    url_job_info = (
+        f"{job_mock.auth._endpoint()}/projects/{job_mock.project_id}/"
+        f"jobs/{job_mock.job_id}"
+    )
+    requests_mock.get(url=url_job_info, json={"data": {}})
 
-        jb = workflow_mock.run_job(input_parameters_json)
-        assert isinstance(jb, Job)
-        assert jb.job_id == job_mock.job_id
+    input_parameters_json = (
+        Path(__file__).resolve().parent / "mock_data/input_params_simple.json"
+    )
+    job = workflow_mock.run_job(input_parameters_json, name=JOB_NAME)
+    assert isinstance(job, Job)
+    assert job.job_id == job_mock.job_id
 
 
-def test_helper_run_parallel_jobs_dry_run(workflow_mock, project_max_concurrent_jobs):
+def test_helper_run_parallel_jobs_dry_run(
+    workflow_mock, project_mock_max_concurrent_jobs
+):
     # pylint: disable=dangerous-default-value
     input_parameters_list = [
         {"sobloo-s2-l1c-aoiclipped:1": {"ids": ["S2abc"], "limit": 1}},
@@ -500,18 +323,18 @@ def test_helper_run_parallel_jobs_dry_run(workflow_mock, project_max_concurrent_
 
     example_response = {
         "error": None,
-        "data": {"id": "jobid_123", "status": "SUCCEEDED", "mode": "DRY_RUN"},
+        "data": {"id": JOB_ID, "status": "SUCCEEDED", "mode": "DRY_RUN"},
     }
 
-    with project_max_concurrent_jobs(10) as m:
+    with project_mock_max_concurrent_jobs(10) as m:
         for i, _ in enumerate(input_parameters_list):
-            job_name = f"{workflow_mock.info['name']}_{i}_py"
-            job_url = (
+            job_name = f"{workflow_mock._info['name']}_{i}_py"
+            url_job = (
                 f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.project_id}/"
                 f"workflows/{workflow_mock.workflow_id}/jobs?name={job_name}"
             )
-            print(job_url)
-            m.post(url=job_url, json={"data": {"id": job_name}})
+            print(url_job)
+            m.post(url=url_job, json={"data": {"id": job_name}})
             m.get(
                 url=f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.project_id}/"
                 f"jobs/{job_name}",
@@ -524,11 +347,11 @@ def test_helper_run_parallel_jobs_dry_run(workflow_mock, project_max_concurrent_
     assert isinstance(jb, JobCollection)
     assert len(jb.jobs) == 2
     for job in jb.jobs:
-        assert job.info["mode"] == "DRY_RUN"
+        assert job._info["mode"] == "DRY_RUN"
 
 
 def test_helper_run_parallel_jobs_all_fails(
-    workflow_mock, jobtask_mock, project_max_concurrent_jobs
+    workflow_mock, jobtask_mock, project_mock_max_concurrent_jobs
 ):
     # pylint: disable=dangerous-default-value
     input_parameters_list = [
@@ -538,11 +361,11 @@ def test_helper_run_parallel_jobs_all_fails(
 
     response_failed = {
         "error": None,
-        "data": {"id": "jobid_123", "status": "FAILED", "mode": "DRY_RUN"},
+        "data": {"id": JOB_ID, "status": "FAILED", "mode": "DRY_RUN"},
     }
-    with project_max_concurrent_jobs(10) as m:
+    with project_mock_max_concurrent_jobs(10) as m:
         for i, _ in enumerate(input_parameters_list):
-            job_name = f"{workflow_mock.info['name']}_{i}_py"
+            job_name = f"{workflow_mock._info['name']}_{i}_py"
             job_url = (
                 f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.project_id}/"
                 f"workflows/{workflow_mock.workflow_id}/jobs?name={job_name}"
@@ -569,14 +392,14 @@ def test_helper_run_parallel_jobs_all_fails(
         )
         assert isinstance(jb, JobCollection)
         assert len(jb.jobs) == 2
-        assert jb.get_jobs_status() == {
+        assert jb.status == {
             "workflow_name_123_0_py": "FAILED",
             "workflow_name_123_1_py": "FAILED",
         }
 
 
 def test_helper_run_parallel_jobs_one_fails(
-    workflow_mock, jobtask_mock, project_max_concurrent_jobs
+    workflow_mock, project_mock_max_concurrent_jobs
 ):
     input_parameters_list = [
         {"sobloo-s2-l1c-aoiclipped:1": {"ids": ["S2abc"], "limit": 1}},
@@ -586,17 +409,17 @@ def test_helper_run_parallel_jobs_one_fails(
     responses = [
         {
             "error": None,
-            "data": {"id": "jobid_123", "status": "SUCCEEDED", "mode": "DRY_RUN"},
+            "data": {"id": JOB_ID, "status": "SUCCEEDED", "mode": "DRY_RUN"},
         },
         {
             "error": None,
-            "data": {"id": "jobid_123", "status": "FAILED", "mode": "DRY_RUN"},
+            "data": {"id": JOB_ID, "status": "FAILED", "mode": "DRY_RUN"},
         },
     ]
 
-    with project_max_concurrent_jobs(10) as m:
+    with project_mock_max_concurrent_jobs(10) as m:
         for i, _ in enumerate(input_parameters_list):
-            job_name = f"{workflow_mock.info['name']}_{i}_py"
+            job_name = f"{workflow_mock._info['name']}_{i}_py"
             job_url = (
                 f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.project_id}/"
                 f"workflows/{workflow_mock.workflow_id}/jobs?name={job_name}"
@@ -611,10 +434,10 @@ def test_helper_run_parallel_jobs_one_fails(
                 f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.project_id}/jobs/{job_name}"
                 f"/tasks/"
             )
-            m.get(url=url_job_tasks, json={"data": [{"id": jobtask_mock.jobtask_id}]})
+            m.get(url=url_job_tasks, json={"data": [{"id": JOBTASK_ID}]})
             url_log = (
                 f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.project_id}/jobs/"
-                f"{job_name}/tasks/{jobtask_mock.jobtask_id}/logs"
+                f"{job_name}/tasks/{JOBTASK_ID}/logs"
             )
             m.get(url_log, json="")
 
@@ -623,13 +446,17 @@ def test_helper_run_parallel_jobs_one_fails(
         )
         assert isinstance(jb, JobCollection)
         assert len(jb.jobs) == 2
-        assert jb.get_jobs_status() == {
+        assert jb.status == {
             "workflow_name_123_0_py": "SUCCEEDED",
             "workflow_name_123_1_py": "FAILED",
         }
 
 
-def test_helper_run_parallel_jobs_default(workflow_mock, project_max_concurrent_jobs):
+@pytest.mark.skip
+def test_helper_run_parallel_jobs_default(
+    workflow_mock, project_mock_max_concurrent_jobs
+):
+    """Takes 100sec."""
     # pylint: disable=dangerous-default-value
     input_parameters_list = [
         {"sobloo-s2-l1c-aoiclipped:1": {"ids": ["S2abc"], "limit": 1}},
@@ -637,12 +464,12 @@ def test_helper_run_parallel_jobs_default(workflow_mock, project_max_concurrent_
     ] * 10
     example_response = {
         "error": None,
-        "data": {"id": "jobid_123", "status": "SUCCEEDED", "mode": "DEFAULT"},
+        "data": {"id": JOB_ID, "status": "SUCCEEDED", "mode": "DEFAULT"},
     }
 
-    with project_max_concurrent_jobs(10) as m:
+    with project_mock_max_concurrent_jobs(10) as m:
         for i, _ in enumerate(input_parameters_list):
-            job_name = f"{workflow_mock.info['name']}_{i}_py"
+            job_name = f"{workflow_mock._info['name']}_{i}_py"
             job_url = (
                 f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.project_id}/"
                 f"workflows/{workflow_mock.workflow_id}/jobs?name={job_name}"
@@ -660,11 +487,11 @@ def test_helper_run_parallel_jobs_default(workflow_mock, project_max_concurrent_
     assert isinstance(jb, JobCollection)
     assert len(jb.jobs) == 20
     for job in jb.jobs:
-        assert job.info["mode"] == "DEFAULT"
+        assert job._info["mode"] == "DEFAULT"
 
 
 def test_helper_run_parallel_jobs_fail_concurrent_jobs(
-    workflow_mock, project_max_concurrent_jobs
+    workflow_mock, project_mock_max_concurrent_jobs
 ):
     # pylint: disable=dangerous-default-value
     input_parameters_list = [
@@ -673,12 +500,12 @@ def test_helper_run_parallel_jobs_fail_concurrent_jobs(
     ] * 10
     example_response = {
         "error": None,
-        "data": {"id": "jobid_123", "status": "SUCCEEDED", "mode": "DEFAULT"},
+        "data": {"id": JOB_ID, "status": "SUCCEEDED", "mode": "DEFAULT"},
     }
 
-    with project_max_concurrent_jobs(1) as m:
+    with project_mock_max_concurrent_jobs(1) as m:
         for i, _ in enumerate(input_parameters_list):
-            job_name = f"{workflow_mock.info['name']}_{i}_py"
+            job_name = f"{workflow_mock._info['name']}_{i}_py"
             job_url = (
                 f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.project_id}/"
                 f"workflows/{workflow_mock.workflow_id}/jobs?name={job_name}"
@@ -701,7 +528,7 @@ def test_test_jobs_parallel_live(workflow_live):
     input_parameters_list = [
         {
             "sobloo-s2-l1c-aoiclipped:1": {
-                "time": "2019-01-01T00:00:00Z/2020-12-31T00:00:00Z",
+                "time": "2019-01-01T00:00:00Z/2020-12-31T23:59:59Z",
                 "limit": 1,
                 "bbox": [13.375966, 52.515068, 13.378314, 52.516639],
             },
@@ -709,7 +536,7 @@ def test_test_jobs_parallel_live(workflow_live):
         },
         {
             "sobloo-s2-l1c-aoiclipped:1": {
-                "time": "2019-12-01T00:00:00Z/2020-12-31T00:00:00Z",
+                "time": "2019-12-01T00:00:00Z/2020-12-31T23:59:59Z",
                 "limit": 1,
                 "bbox": [13.375966, 52.515068, 13.378314, 52.516639],
             },
@@ -724,9 +551,9 @@ def test_test_jobs_parallel_live(workflow_live):
     for input_parameters in input_parameters_list:
         input_parameters.update({"config": {"mode": "DRY_RUN"}})
     for index, job in enumerate(jb.jobs):
-        assert job.get_status() == "SUCCEEDED"
-        assert job.info["inputs"] == input_parameters_list[index]
-        assert job.info["mode"] == "DRY_RUN"
+        assert job.status == "SUCCEEDED"
+        assert job._info["inputs"] == input_parameters_list[index]
+        assert job._info["mode"] == "DRY_RUN"
 
 
 @pytest.mark.live
@@ -734,7 +561,7 @@ def test_run_jobs_parallel_live(workflow_live):
     input_parameters_list = [
         {
             "sobloo-s2-l1c-aoiclipped:1": {
-                "time": "2019-01-01T00:00:00Z/2020-12-31T00:00:00Z",
+                "time": "2019-01-01T00:00:00Z/2020-12-31T23:59:59Z",
                 "limit": 1,
                 "bbox": [13.375966, 52.515068, 13.378314, 52.516639],
             },
@@ -742,7 +569,7 @@ def test_run_jobs_parallel_live(workflow_live):
         },
         {
             "sobloo-s2-l1c-aoiclipped:1": {
-                "time": "2019-12-01T00:00:00Z/2020-12-31T00:00:00Z",
+                "time": "2019-12-01T00:00:00Z/2020-12-31T23:59:59Z",
                 "limit": 1,
                 "bbox": [13.375966, 52.515068, 13.378314, 52.516639],
             },
@@ -753,9 +580,9 @@ def test_run_jobs_parallel_live(workflow_live):
     jb = workflow_live.run_jobs_parallel(input_parameters_list=input_parameters_list)
     assert isinstance(jb, JobCollection)
     for index, job in enumerate(jb.jobs):
-        assert job.get_status() == "SUCCEEDED"
-        assert job.info["inputs"] == input_parameters_list[index]
-        assert job.info["mode"] == "DEFAULT"
+        assert job.status == "SUCCEEDED"
+        assert job._info["inputs"] == input_parameters_list[index]
+        assert job._info["mode"] == "DEFAULT"
 
 
 @pytest.mark.live
@@ -770,9 +597,9 @@ def test_test_job_live(workflow_live):
     with open(input_parameters_json) as src:
         job_info_params = json.load(src)
         job_info_params.update({"config": {"mode": "DRY_RUN"}})
-        assert jb.info["inputs"] == job_info_params
-        assert jb.info["mode"] == "DRY_RUN"
-    assert jb.get_status() == "SUCCEEDED"
+        assert jb._info["inputs"] == job_info_params
+        assert jb._info["mode"] == "DRY_RUN"
+    assert jb.status == "SUCCEEDED"
 
 
 @pytest.mark.live
@@ -780,54 +607,33 @@ def test_run_job_live(workflow_live):
     input_parameters_json = (
         Path(__file__).resolve().parent / "mock_data/input_params_simple.json"
     )
-    jb = workflow_live.run_job(input_parameters_json, track_status=True, name="aa")
+    jb = workflow_live.run_job(input_parameters_json, track_status=True, name=JOB_NAME)
     assert isinstance(jb, Job)
     with open(input_parameters_json) as src:
-        assert jb.info["inputs"] == json.load(src)
-        assert jb.info["mode"] == "DEFAULT"
-    assert jb.get_status() == "SUCCEEDED"
-    assert jb.info["name"] == "aa_py"
+        assert jb._info["inputs"] == json.load(src)
+        assert jb._info["mode"] == "DEFAULT"
+    assert jb.status == "SUCCEEDED"
+    assert jb._info["name"] == JOB_NAME + "_py"
 
 
-def test_get_jobs(workflow_mock):
-    job_id = "87c285b4-d69b-42a4-bdc5-6fe6d0ddcbbd"
-    with requests_mock.Mocker() as m:
-        url_jobs = (
-            f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.project_id}/jobs"
-        )
-        json_jobs = {
-            "data": [
-                {
-                    "id": job_id,
-                    "status": "SUCCEEDED",
-                    "inputs": {},
-                    "error": {},
-                    "workflowId": "123456",
-                },
-                {
-                    "id": job_id,
-                    "status": "SUCCEEDED",
-                    "inputs": {},
-                    "error": {},
-                    "workflowId": workflow_mock.workflow_id,
-                },
-            ]
-        }
-        m.get(url=url_jobs, json=json_jobs)
+def test_get_jobs(workflow_mock, requests_mock):
+    url_job_info = (
+        f"{workflow_mock.auth._endpoint()}/projects/"
+        f"{workflow_mock.project_id}/jobs/{JOB_ID}"
+    )
 
-        url_job_info = (
-            f"{workflow_mock.auth._endpoint()}/projects/"
-            f"{workflow_mock.project_id}/jobs/{job_id}"
-        )
-        m.get(url=url_job_info, json={"data": {"xyz": 789}, "error": {}})
+    requests_mock.get(
+        url=url_job_info,
+        json={"data": {"xyz": 789, "mode": "DEFAULT"}, "error": {}},
+    )
 
-        jobcollection = workflow_mock.get_jobs()
-        assert isinstance(jobcollection, JobCollection)
-        assert isinstance(jobcollection.jobs[0], Job)
-        assert jobcollection.jobs[0].job_id == job_id
-        assert (
-            len(jobcollection.jobs) == 1
-        )  # Filters out the job that is not associated with the workflow object
+    jobcollection = workflow_mock.get_jobs()
+    assert isinstance(jobcollection, JobCollection)
+    assert isinstance(jobcollection.jobs[0], Job)
+    assert jobcollection.jobs[0].job_id == JOB_ID
+    assert (
+        len(jobcollection.jobs) == 1
+    )  # Filters out the job that is not associated with the workflow object
 
 
 @pytest.mark.skip
@@ -838,36 +644,32 @@ def test_get_jobs_live(workflow_live):
     assert isinstance(jobcollection, list)
     assert isinstance(jobcollection.jobs[0], Job)
     assert all(
-        [j.info["workflowId"] == workflow_live.workflow_id for j in jobcollection.jobs]
+        [j._info["workflowId"] == workflow_live.workflow_id for j in jobcollection.jobs]
     )
 
 
-# TODO: Resolve
-# def test_update_name(workflow_mock, caplog):
-#     new_name = "new_workflow_name"
-#     with requests_mock.Mocker() as m:
-#         url_update_name = (
-#             f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.auth.project_id}/workflows/"
-#             f"{workflow_mock.workflow_id}"
-#         )
-#         json_new_properties = {"data": {}, "error": {}}
-#         m.post(
-#             url=url_update_name,
-#             json=json_new_properties,
-#         )
-#
-#         workflow_mock.update_name(name=new_name)
-#     assert f"Updated workflow name: {new_name}" in caplog.text
+def test_update_name(workflow_mock, requests_mock):
+    new_name = "new_workflow_name"
+    url_update_name = (
+        f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.auth.project_id}/workflows/"
+        f"{workflow_mock.workflow_id}"
+    )
+    json_new_properties = {"data": {}, "error": {}}
+    requests_mock.put(
+        url=url_update_name,
+        json=json_new_properties,
+    )
+
+    workflow_mock.update_name(name=new_name)
+    # TODO:caplog, capture logger
 
 
-@pytest.mark.skip
-# TODO: Resolve
-def test_delete(workflow_mock, caplog):
-    with requests_mock.Mocker() as m:
-        delete_url = (
-            f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.project_id}/workflows/"
-            f"{workflow_mock.workflow_id}"
-        )
-        m.delete(url=delete_url)
-        workflow_mock.delete()
-    assert f"Successfully deleted workflow: {workflow_mock.workflow_id}" in caplog.text
+def test_delete(workflow_mock, requests_mock):
+    delete_url = (
+        f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.project_id}/workflows/"
+        f"{workflow_mock.workflow_id}"
+    )
+    requests_mock.delete(url=delete_url)
+
+    workflow_mock.delete()
+    # TODO:caplog, capture logger
