@@ -57,7 +57,7 @@ def cfg_default(defult_path="./config.json"):
 )
 @click.option("--env", default="com")
 @click.pass_context
-def main(ctx, project_id, project_api_key, cfg_file, env):
+def up42(ctx, project_id, project_api_key, cfg_file, env):
     ctx.ensure_object(dict)
     if project_id and project_api_key:
         ctx.obj = Auth(project_id=project_id, project_api_key=project_api_key, env=env)
@@ -65,7 +65,7 @@ def main(ctx, project_id, project_api_key, cfg_file, env):
         ctx.obj = Auth(cfg_file=cfg_file, env=env)
 
 
-COMMAND = main.command(context_settings=CONTEXT_SETTINGS)
+COMMAND = up42.command(context_settings=CONTEXT_SETTINGS)
 
 
 @COMMAND
@@ -190,7 +190,7 @@ def validate_manifest(auth, manifest_json):
 
 
 # Project
-@main.group()
+@up42.group()
 @click.pass_context
 def project(ctx):
     """
@@ -269,7 +269,7 @@ def update_project_settings(
 def workflows_from_context():
     class OptionChoiceFromContext(click.Option):
         def full_process_value(self, ctx, value):
-            workflow_names = [wkf.info["name"] for wkf in ctx.obj.get_workflows()]
+            workflow_names = [wkf._info["name"] for wkf in ctx.obj.get_workflows()]
             self.type = click.Choice(workflow_names)
             return super(OptionChoiceFromContext, self).full_process_value(ctx, value)
 
@@ -297,7 +297,7 @@ def workflow_from_name(project, workflow_name):
 
 
 # Workflows
-@main.group()
+@up42.group()
 @click.pass_context
 @click.option(
     "-wid",
@@ -322,9 +322,9 @@ def workflow(ctx, workflow_id):
 COMMAND_WORKFLOW = workflow.command(context_settings=CONTEXT_SETTINGS)
 
 
-@workflow.command("get-info", context_settings=CONTEXT_SETTINGS)
+@workflow.command("info", context_settings=CONTEXT_SETTINGS)
 @click.pass_obj
-def workflow_get_info(workflow):
+def workflow_info(workflow):
     """
     Get information about the workflow.
     """
@@ -350,14 +350,14 @@ def update_name(ctx, name, description):
     """
     Update the workflow name.
     """
-    logger.info("Current info: {}".format(ctx.obj.info))
+    logger.info("Current info: {}".format(ctx.obj._info))
     if click.confirm(
-        f"Are you sure you want to change the name '{ctx.obj.info.get('name')}' to '{name}'?",
+        f"Are you sure you want to change the name '{ctx.obj._info.get('name')}' to '{name}'?",
         abort=True,
     ):
         ctx.obj.update_name(name, description)
         ctx.obj = Workflow(ctx.obj.auth, ctx.obj.project_id, ctx.obj.workflow_id)
-        logger.info("New info: {}".format(ctx.obj.info))
+        logger.info("New info: {}".format(ctx.obj._info))
 
 
 @COMMAND_WORKFLOW
@@ -366,9 +366,9 @@ def delete(workflow):
     """
     Delete the workflow.
     """
-    logger.info("Current info: {}".format(workflow.info))
+    logger.info("Current info: {}".format(workflow._info))
     if click.confirm(
-        f"Are you sure you want to delete workflow '{workflow.info.get('name')}'?",
+        f"Are you sure you want to delete workflow '{workflow._info.get('name')}'?",
         abort=True,
     ):
         workflow.delete()
@@ -467,7 +467,7 @@ def run_job(workflow, input_parameters_json, track):
 
 
 # Jobs
-@main.group()
+@up42.group()
 @click.pass_context
 @click.option(
     "-jid",
@@ -492,13 +492,13 @@ def job(ctx, job_id):
 COMMAND_JOB = job.command(context_settings=CONTEXT_SETTINGS)
 
 
-@job.command("get-info", context_settings=CONTEXT_SETTINGS)
+@job.command("info", context_settings=CONTEXT_SETTINGS)
 @click.pass_obj
-def job_get_info(job):
+def job_info(job):
     """
     Get information about the job.
     """
-    logger.info(pprint_json(job.info))
+    logger.info(pprint_json(job._info))
 
 
 @COMMAND_JOB
@@ -507,7 +507,7 @@ def cancel_job(job):
     """
     Cancel a job that is running.
     """
-    job.get_status()
+    logger.info(job.status)
     if click.confirm("Are you sure you want to cancel job with job id '{job.job_id}'?"):
         job.cancel_job()
 
@@ -580,7 +580,7 @@ def get_status(job):
     """
     Get the job status.
     """
-    logger.info(job.get_status())
+    logger.info(job.status)
 
 
 @COMMAND_JOB
@@ -602,7 +602,7 @@ def track_status(job, interval):
 # Catalog
 
 
-@main.group()
+@up42.group()
 @click.pass_context
 def catalog(ctx):
     """
