@@ -6,6 +6,8 @@ import shutil
 import tempfile
 import tarfile
 import math
+import warnings
+import functools
 
 import folium
 from folium.plugins import Draw
@@ -23,11 +25,11 @@ from tqdm import tqdm
 import matplotlib.pyplot as plt
 
 
-# truncate log messages > 2000 characters (e.g. huge geometries)
-LOG_FORMAT = "%(asctime)s - %(name)s - %(levelname)s - %(message).2000s"
-
-
-def get_logger(name, level=logging.INFO):
+def get_logger(
+    name,
+    level=logging.INFO,
+    verbose=False,
+):
     """
     Use level=logging.CRITICAL to disable temporarily.
     """
@@ -36,7 +38,12 @@ def get_logger(name, level=logging.INFO):
     # create console handler and set level to debug
     ch = logging.StreamHandler()
     ch.setLevel(level)
-    formatter = logging.Formatter(LOG_FORMAT)
+    if verbose:
+        log_format = "%(asctime)s - %(name)s - %(levelname)s - %(message)"
+    else:
+        # hide logger module & level, truncate log messages > 2000 characters (e.g. huge geometries)
+        log_format = "%(asctime)s - %(message).2000s"
+    formatter = logging.Formatter(log_format)
     ch.setFormatter(formatter)
     logger.addHandler(ch)
     logger.propagate = False
@@ -46,6 +53,37 @@ def get_logger(name, level=logging.INFO):
 logger = get_logger(__name__)
 
 
+def deprecation(
+    function_name: str,
+    replacement_name: str,
+    version: str = "0.13.0",
+    extra_message: str = "",
+):
+    """
+    Decorator for custom deprecation warnings.
+
+    Args:
+        function_name: Name of the to be deprecated function.
+        replacement_name: Name of the replacement function.
+        version: The package version in which the deprecation will happen.
+        extra_message: Optional message after default deprecation warning.
+    """
+
+    def actual_decorator(func):
+        @functools.wraps(func)
+        def wrapper(*args, **kwargs):
+            message = (
+                f"`{function_name}` will be deprecated in version {version}, "
+                f"use `{replacement_name}` instead! {extra_message}"
+            )
+            warnings.warn(message, DeprecationWarning, stacklevel=2)
+            return func(*args, **kwargs)
+
+        return wrapper
+
+    return actual_decorator
+
+
 def download_results_from_gcs(
     download_url: str, output_directory: Union[str, Path]
 ) -> List[str]:
@@ -78,10 +116,15 @@ def download_results_from_gcs(
     with tarfile.open(tgz_file) as tar:
         tar.extractall(path=output_directory)
         output_folder_path = output_directory / "output"
+        out_filepaths = []
         for src_path in output_folder_path.glob("**/*"):
             dst_path = output_directory / src_path.relative_to(output_folder_path)
             shutil.move(str(src_path), str(dst_path))
-        out_filepaths = [str(x) for x in output_directory.glob("**/*") if x.is_file()]
+            if dst_path.is_dir():
+                out_filepaths += [str(x) for x in dst_path.glob("**/*")]
+            elif dst_path.is_file():
+                out_filepaths.append(str(dst_path))
+        output_folder_path.rmdir()
 
     logger.info(
         f"Download successful of {len(out_filepaths)} files to output_directory "
@@ -593,3 +636,32 @@ def fc_to_query_geometry(
             elif squash_multiple_features == "first":
                 query_geometry = fc["features"][0]["geometry"]
     return query_geometry
+
+
+def filter_jobs_on_mode(
+    jobs_json: List[dict], test_jobs: bool = True, real_jobs: bool = True
+) -> List[dict]:
+    """
+    Filter jobs according to selected mode.
+
+    Args:
+        jobs_json: List of jobs as returned by /jobs endpoint.
+        test_jobs: If returning test jobs or test queries.
+        real_jobs: If returning real jobs.
+
+    Returns:
+        List of filtered jobs.
+
+    Raises:
+        ValueError: When no modes are selected to filter jobs with.
+    """
+    selected_modes = []
+    if test_jobs:
+        selected_modes.append("DRY_RUN")
+    if real_jobs:
+        selected_modes.append("DEFAULT")
+    if not selected_modes:
+        raise ValueError("At least one of test_jobs and real_jobs must be True.")
+    jobs_json = [job for job in jobs_json if job["mode"] in selected_modes]
+    logger.info(f"Returning {selected_modes} jobs.")
+    return jobs_json
