@@ -15,7 +15,12 @@ from up42.auth import Auth
 from up42.job import Job
 from up42.jobcollection import JobCollection
 from up42.tools import Tools
-from up42.utils import get_logger, any_vector_to_fc, fc_to_query_geometry
+from up42.utils import (
+    get_logger,
+    any_vector_to_fc,
+    fc_to_query_geometry,
+    filter_jobs_on_mode,
+)
 
 logger = get_logger(__name__)
 
@@ -30,23 +35,39 @@ class Workflow(Tools):
         self.project_id = project_id
         self.workflow_id = workflow_id
         if self.auth.get_info:
-            self.info = self._get_info()
+            self._info = self.info
 
     def __repr__(self):
+        info = self.info
         return (
-            f"Workflow(workflow_id={self.workflow_id}, project_id={self.project_id}, "
-            f"auth={self.auth}, info={self.info})"
+            f"Workflow(name: {info['name']}, workflow_id: {self.workflow_id}, "
+            f"description: {info['description']}, createdAt: {info['createdAt']}, "
+            f"project_name: {info['name']}, "
+            f"workflow_tasks: {self.workflow_tasks}"
         )
 
-    def _get_info(self) -> Dict:
-        """Gets metadata info from an existing workflow"""
+    @property
+    def info(self) -> Dict:
+        """
+        Gets the workflow metadata information.
+        """
         url = (
             f"{self.auth._endpoint()}/projects/{self.project_id}/workflows/"
             f"{self.workflow_id}"
         )
         response_json = self.auth._request(request_type="GET", url=url)
-        self.info = response_json["data"]
-        return self.info
+        self._info = response_json["data"]
+        return response_json["data"]
+
+    @property
+    def workflow_tasks(self) -> Dict[str, str]:
+        """
+        Gets the building blocks of the workflow as a dictionary with task_name : block-version
+        """
+        logging.getLogger("up42.workflow").setLevel(logging.CRITICAL)
+        workflow_tasks = self.get_workflow_tasks(basic=True)
+        logging.getLogger("up42.workflow").setLevel(logging.INFO)
+        return workflow_tasks  # type: ignore
 
     def get_compatible_blocks(self) -> Dict:
         """
@@ -73,7 +94,7 @@ class Workflow(Tools):
         Get the workflow-tasks of the workflow (Blocks in a workflow are called workflow_tasks)
 
         Args:
-            basic: If selected returns a simplified task-name : task-id` version.
+            basic: If selected returns a simplified task-name : block-version dict.
 
         Returns:
             The workflow task info.
@@ -87,7 +108,7 @@ class Workflow(Tools):
         logger.info(f"Got {len(tasks)} tasks/blocks in workflow {self.workflow_id}.")
 
         if basic:
-            return {task["name"]: task["id"] for task in tasks}
+            return {task["name"]: task["blockVersionTag"] for task in tasks}
         else:
             return tasks
 
@@ -327,8 +348,8 @@ class Workflow(Tools):
                 input_parameters[data_block_name]["limit"] = len(scene_ids)
                 input_parameters[data_block_name].pop("time")
             elif start_date is not None and end_date is not None:
-                datetime = f"{start_date}T00:00:00Z/{end_date}T00:00:00Z"
-                input_parameters[data_block_name]["time"] = datetime
+                time = f"{start_date}T00:00:00Z/{end_date}T23:59:59Z"
+                input_parameters[data_block_name]["time"] = time
 
             if geometry is not None:
                 aoi_fc = any_vector_to_fc(
@@ -459,7 +480,7 @@ class Workflow(Tools):
         logger.info(f"Selected input_parameters: {input_parameters}")
 
         if name is None:
-            name = self.info["name"]
+            name = self._info["name"]
         name = f"{name}_py"  # Temporary recognition of python API usage.
         url = (
             f"{self.auth._endpoint()}/projects/{self.project_id}/"
@@ -517,7 +538,7 @@ class Workflow(Tools):
                 logger.info("+++++++++++++++++++++++++++++++++")
 
         if name is None:
-            name = self.info["name"]
+            name = self._info["name"]
 
         jobs_list = []
         job_nr = 0
@@ -682,19 +703,23 @@ class Workflow(Tools):
         )
         return jobcollection
 
-    def get_jobs(self, return_json: bool = False) -> Union[JobCollection, List[Dict]]:
+    def get_jobs(
+        self, return_json: bool = False, test_jobs: bool = True, real_jobs: bool = True
+    ) -> Union[JobCollection, List[Dict]]:
         """
         Get all jobs associated with the workflow as a JobCollection or json.
 
         Args:
             return_json: If true, returns the job info jsons instead of a JobCollection.
+            test_jobs: Return test jobs or test queries.
+            real_jobs: Return real jobs.
 
         Returns:
             A JobCollection, or alternatively the jobs info as json.
         """
         url = f"{self.auth._endpoint()}/projects/{self.project_id}/jobs"
         response_json = self.auth._request(request_type="GET", url=url)
-        jobs_json = response_json["data"]
+        jobs_json = filter_jobs_on_mode(response_json["data"], test_jobs, real_jobs)
 
         jobs_workflow_json = [
             j for j in jobs_json if j["workflowId"] == self.workflow_id
@@ -730,6 +755,7 @@ class Workflow(Tools):
             f"{self.workflow_id}"
         )
         self.auth._request(request_type="PUT", url=url, data=properties_to_update)
+        # TODO: Renew info
         logger.info(f"Updated workflow name: {properties_to_update}")
 
     def delete(self) -> None:
@@ -746,7 +772,9 @@ class Workflow(Tools):
 
     @property
     def max_concurrent_jobs(self) -> int:
-        """Gets the maximum number of concurrent jobs allowed by the project settings."""
+        """
+        Gets the maximum number of concurrent jobs allowed by the project settings.
+        """
         url = f"{self.auth._endpoint()}/projects/{self.project_id}/settings"
         response_json = self.auth._request(request_type="GET", url=url)
         project_settings = response_json["data"]
